@@ -37,6 +37,8 @@
 #include <QPainter>
 #include <QCheckBox>
 #include <QPainterPath>
+#include <QTextLayout>
+#include <QTextOption>
 
 DWIDGET_USE_NAMESPACE
 
@@ -81,6 +83,7 @@ DFontPreviewItemDelegate::DFontPreviewItemDelegate(QAbstractItemView *parent)
 
 void DFontPreviewItemDelegate::paintForegroundCheckBox(QPainter *painter, const QStyleOptionViewItem &option, const FontData &itemData) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paintForegroundCheckBox";
     int checkBoxWidth = CHECKBOX_SIZE - 4;
     int checkBoxHeight = CHECKBOX_SIZE - 4;
 
@@ -88,17 +91,25 @@ void DFontPreviewItemDelegate::paintForegroundCheckBox(QPainter *painter, const
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        // qDebug() << "Using compact mode for checkbox positioning";
         rect = QRect(option.rect.x() + 25, option.rect.y() + 6, checkBoxWidth, checkBoxHeight);
     }
 #endif
 
     QStyleOptionButton checkBoxOption;
     checkBoxOption.state |= QStyle::State_Enabled;
-    checkBoxOption.state |= itemData.isEnabled() ? QStyle::State_On : QStyle::State_Off;
+    if (itemData.isEnabled()) {
+        // qDebug() << "Checkbox is enabled, setting State_On";
+        checkBoxOption.state |= QStyle::State_On;
+    } else {
+        // qDebug() << "Checkbox is disabled, setting State_Off";
+        checkBoxOption.state |= QStyle::State_Off;
+    }
     checkBoxOption.rect = rect;
 
     QCheckBox checkBox;
     DApplication::style()->drawPrimitive(QStyle::PE_IndicatorCheckBox, &checkBoxOption, painter, &checkBox);
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paintForegroundCheckBox";
 }
 
 
@@ -115,6 +126,7 @@ void DFontPreviewItemDelegate::paintForegroundCheckBox(QPainter *painter, const
 *************************************************************************/
 void DFontPreviewItemDelegate::paintForegroundFontName(QPainter *painter, const QStyleOptionViewItem &option, const FontData &itemData) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paintForegroundFontName";
     QFont nameFont = painter->font();
     nameFont.setPixelSize(DFontSizeManager::instance()->fontPixelSize(DFontSizeManager::T6));
     painter->setFont(nameFont);
@@ -129,6 +141,7 @@ void DFontPreviewItemDelegate::paintForegroundFontName(QPainter *painter, const
     QColor fillColor = palette.color(DPalette::TextTips);
     // SP3--禁用置灰(539)
     if (!itemData.isEnabled()) {
+        // qDebug() << "Font is disabled, setting alpha to 0.6";
         fillColor.setAlphaF(0.6);
     }
     painter->setPen(QPen(fillColor));
@@ -137,6 +150,7 @@ void DFontPreviewItemDelegate::paintForegroundFontName(QPainter *painter, const
                                option.rect.width() - 20, FONT_NAME_HEIGHT);
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        // qDebug() << "Using compact mode for font name height";
         fontNameRect.setHeight(FONT_NAME_COMPACT_HEIGHT);
     }
 #endif
@@ -144,6 +158,7 @@ void DFontPreviewItemDelegate::paintForegroundFontName(QPainter *painter, const
     QFontMetrics mt(nameFont);//特殊图案字体下截断字体名称/*UT000539*/
     QString elidedText = mt.elidedText(itemData.strFontName, Qt::ElideRight, option.rect.width() - 120);
     painter->drawText(fontNameRect, Qt::AlignLeft | Qt::AlignVCenter, elidedText);
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paintForegroundFontName";
 }
 
 /*************************************************************************
@@ -159,17 +174,21 @@ void DFontPreviewItemDelegate::paintForegroundFontName(QPainter *painter, const
 *************************************************************************/
 void DFontPreviewItemDelegate::paintForegroundCollectIcon(QPainter *painter, const QStyleOptionViewItem &option, const FontData &itemData) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paintForegroundCollectIcon";
     DGuiApplicationHelper *appHelper = DGuiApplicationHelper::instance();
     QString strImgPrefix = (DGuiApplicationHelper::DarkType == appHelper->themeType()) ? QString("dark_") : QString("");
 
     QString iconStatus;
     IconStatus status = itemData.getHoverState();
     if (IconHover == status) {
+        // qDebug() << "Icon hover state detected";
         iconStatus = QString("hover");
     } else if (IconPress == status) {
+        // qDebug() << "Icon press state detected";
         iconStatus = QString("press");
         strImgPrefix = "";
     } else {
+        // qDebug() << "Icon normal state detected";
         iconStatus = QString("normal");
     }
 
@@ -179,9 +198,11 @@ void DFontPreviewItemDelegate::paintForegroundCollectIcon(QPainter *painter, con
     QString strImageSrc;
     QPixmap pixmap;
     if (itemData.isCollected()) {
+        // qDebug() << "Font is collected, using collection icon";
         strImageSrc = QString("://%1collection_%2.svg").arg(strImgPrefix).arg(iconStatus);
         pixmap = Utils::renderSVG(strImageSrc, QSize(COLLECT_ICON_SIZE, COLLECT_ICON_SIZE));
     } else {
+        // qDebug() << "Font is not collected, using uncollection icon";
         strImageSrc = QString("://%1uncollection_%2.svg").arg(strImgPrefix).arg(iconStatus);
         pixmap = Utils::renderSVG(strImageSrc, QSize(COLLECT_ICON_SIZE, COLLECT_ICON_SIZE));
     }
@@ -191,6 +212,7 @@ void DFontPreviewItemDelegate::paintForegroundCollectIcon(QPainter *painter, con
                                       COLLECT_ICON_SIZE, COLLECT_ICON_SIZE);
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        // qDebug() << "Using compact mode for collect icon positioning";
         collectIconRealRect = QRect(option.rect.right() - COLLECT_ICON_SIZE - COLLECT_ICON_RIGHT_MARGIN,
                                               option.rect.top() + COLLECT_ICON_TOP_COMPACT_MARGIN,
                                               COLLECT_ICON_SIZE, COLLECT_ICON_SIZE);
@@ -203,6 +225,7 @@ void DFontPreviewItemDelegate::paintForegroundCollectIcon(QPainter *painter, con
 
     // 针对鼠标按下时进行处理
     if (IconPress == status) {
+        // qDebug() << "Processing icon press state with color transformation";
         QImage originImage = pixmap.toImage();  // 将原始图片转为image
         int iWidth = originImage.width();
         int iHeight = originImage.height();
@@ -219,9 +242,11 @@ void DFontPreviewItemDelegate::paintForegroundCollectIcon(QPainter *painter, con
 
         painter->drawPixmap(collectIconRealRect, QPixmap::fromImage(tempImage));    // 使用新图片绘制
     } else {
+        // qDebug() << "Using original pixmap for drawing";
         painter->drawPixmap(collectIconRealRect, pixmap);   // 使用原始图片绘制
     }
 
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paintForegroundCollectIcon";
 }
 
 /*************************************************************************
@@ -236,6 +261,7 @@ void DFontPreviewItemDelegate::paintForegroundCollectIcon(QPainter *painter, con
 
 QRect DFontPreviewItemDelegate::adjustPreviewRect(const QRect bgRect) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::adjustPreviewRect";
     QRect fontPreviewRect;
     int fontRectWidth = bgRect.width() - FONT_PREVIEW_LEFT_MARGIN - FONT_PREVIEW_RIGHT_MARGIN;
     fontPreviewRect = QRect(bgRect.x() + FONT_PREVIEW_LEFT_MARGIN, bgRect.y() + FONT_PREVIEW_TOP_MARGIN,
@@ -243,10 +269,12 @@ QRect DFontPreviewItemDelegate::adjustPreviewRect(const QRect bgRect) const
 
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        // qDebug() << "Using compact mode for preview rect adjustment";
         fontPreviewRect = QRect(bgRect.x() + FONT_PREVIEW_LEFT_MARGIN, bgRect.y() + FONT_PREVIEW_TOP_COMPACT_MARGIN,
                                 fontRectWidth, bgRect.height() - FONT_PREVIEW_TOP_COMPACT_MARGIN - FONT_PREVIEW_BOTTOM_COMPACT_MARGIN);
     }
 #endif
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::adjustPreviewRect";
     return fontPreviewRect;
 }
 
@@ -262,19 +290,43 @@ QRect DFontPreviewItemDelegate::adjustPreviewRect(const QRect bgRect) const
 *************************************************************************/
 QPoint DFontPreviewItemDelegate::adjustPreviewFontBaseLinePoint(const QRect &fontPreviewRect, const QFontMetrics &previewFontMetrics) const
 {
-    Q_UNUSED(previewFontMetrics);
-    /* 部分不规则的字体无法获取到有效QFontMetrics::height(),即 QFontMetrics::ascent(), QFontMetrics::descent()无效. */
-//    int baseLineY = 0;
-//    if (previewFontMetrics.ascent() == previewFontMetrics.descent()) {
-//        baseLineY = fontPreviewRect.bottom() - fontPreviewRect.height() / 2;
-//    } else {
-//        baseLineY = fontPreviewRect.bottom() - (fontPreviewRect.height() - previewFontMetrics.height()) / 2;
-//    }
-    /* Bug#20555 调整descent值，用来调整预览效果 UT000591 */
-    int commonFontDescent = fontPreviewRect.height() / 5;
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::adjustPreviewFontBaseLinePoint";
+    // 确保水平位置与字体名称对齐 - 使用预览区域的左边界，这应该与字体名称对齐
     int baseLineX = fontPreviewRect.x();
-    int baseLineY = fontPreviewRect.bottom() - commonFontDescent;
+    int baseLineY;
+    
+    if (previewFontMetrics.height() > 0 && previewFontMetrics.ascent() > 0 && previewFontMetrics.descent() >= 0) {
+        // 使用实际的字体度量信息来计算基线位置
+        // 确保文字不会超出预览区域的边界
+        int actualHeight = previewFontMetrics.height();
+        int availableHeight = fontPreviewRect.height();
+        
+        // 检查字体是否有异常的高度
+        if (actualHeight <= availableHeight * 0.9) {
+            // 字体高度适合预览区域，居中显示
+            int verticalPadding = (availableHeight - actualHeight) / 2;
+            baseLineY = fontPreviewRect.top() + verticalPadding + previewFontMetrics.ascent();
+        } else {
+            // 对于极高的字体（如NotoSansZanabazarSquare），使用更严格的限制
+            int maxAllowedAscent = availableHeight * 0.7; // 限制上升部分不超过70%的可用高度
+            int actualAscent = previewFontMetrics.ascent();
+            
+            if (actualAscent > maxAllowedAscent) {
+                // 如果上升部分太高，强制压缩
+                baseLineY = fontPreviewRect.top() + maxAllowedAscent;
+            } else {
+                // 正常处理但留足够边距
+                int topMargin = availableHeight * 0.1; // 10%上边距
+                baseLineY = fontPreviewRect.top() + topMargin + actualAscent;
+            }
+        }
+    } else {
+        /* Bug#20555 调整descent值，用来调整预览效果 UT000591 */
+        int commonFontDescent = fontPreviewRect.height() / 6; // 从1/5改为1/6，更保守
+        baseLineY = fontPreviewRect.bottom() - commonFontDescent;
+    }
 
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::adjustPreviewFontBaseLinePoint";
     return QPoint(baseLineX, baseLineY);
 }
 
@@ -296,6 +348,7 @@ void DFontPreviewItemDelegate::paintForegroundPreviewFont(QPainter *painter, con
                                                           const QString &familyName, const QString &styleName, bool isEnabled,
                                                           int fontPixelSize, QString &fontPreviewText) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paintForegroundPreviewFont";
     QFont previewFont;
 
     previewFont.setFamily(familyName);
@@ -312,17 +365,67 @@ void DFontPreviewItemDelegate::paintForegroundPreviewFont(QPainter *painter, con
 //    painter->setPen(QPen(option.palette.color(DPalette::Text)));
     //SP3--禁用置灰(539)
     QColor color(option.palette.color(DPalette::Text));
-    if (!isEnabled)
+    if (!isEnabled) {
+        // qDebug() << "Font preview is disabled, setting alpha to 0.6";
         color.setAlphaF(0.6);
+    }
     painter->setPen(QPen(color));
 
     QFontMetrics fontMetric(previewFont);
 
     QString elidedText = fontMetric.elidedText(fontPreviewText, Qt::ElideRight, fontPreviewRect.width());
+    // 强制从左到右的文本方向，避免RTL字体（如Indic Siyaq Numbers）从左边界外开始绘制
+    static const QChar LRM(0x200E);
+    elidedText.prepend(LRM);
 
     QPoint baseLinePoint = adjustPreviewFontBaseLinePoint(fontPreviewRect, fontMetric);
+    
+    // 检查字体边界框是否异常，某些特殊字体可能有异常的度量值
+    QRect textBounds = fontMetric.boundingRect(elidedText);
+    
+    // 特殊处理水平位置异常的字体
+    if (textBounds.x() < -5) {
+        // 如果文本边界框有负x偏移，强制修正基线点的x坐标
+        // 这种情况在某些特殊字体（如NotoSansIndicSiyaqNumbers）中可能出现
+        int correctionOffset = qAbs(textBounds.x()) + 2; // 额外加2像素安全边距
+        baseLinePoint.setX(fontPreviewRect.x() + correctionOffset);
+    }
+    
+    // 特殊处理高度异常的字体，确保不会顶到上一行
+    int actualTextHeight = textBounds.height();
+    int availableHeight = fontPreviewRect.height();
+    if (actualTextHeight > availableHeight * 1.2) {
+        // 如果文本实际高度明显超过可用空间，重新调整Y坐标
+        // 确保文本底部不会超出预览区域底边界
+        int maxAllowedDescent = availableHeight / 4;
+        int adjustedY = fontPreviewRect.bottom() - maxAllowedDescent;
+        if (adjustedY < baseLinePoint.y()) {
+            baseLinePoint.setY(adjustedY);
+        }
+    }
+    
     /* 使用baseline规则绘制预览文字，这样不用考虑特殊字体 UT000591 */
-    painter->drawText(baseLinePoint.x(), baseLinePoint.y(), elidedText);
+    painter->save();
+    painter->setClipRect(fontPreviewRect);
+
+    // 使用 QTextLayout 强制 LTR 排版并消除特殊字体的负左侧承载导致的左越界
+    QTextOption textOption;
+    textOption.setWrapMode(QTextOption::NoWrap);
+    textOption.setAlignment(Qt::AlignLeft);
+    textOption.setTextDirection(Qt::LeftToRight);
+
+    QTextLayout layout(elidedText, previewFont);
+    layout.setTextOption(textOption);
+    layout.beginLayout();
+    QTextLine line = layout.createLine();
+    line.setLineWidth(fontPreviewRect.width());
+    // 将行基线对齐到我们计算的 baseline 上
+    line.setPosition(QPointF(fontPreviewRect.left(), baseLinePoint.y() - line.ascent()));
+    layout.endLayout();
+    layout.draw(painter, QPointF(0, 0));
+
+    painter->restore();
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paintForegroundPreviewFont";
 }
 
 /*************************************************************************
@@ -338,8 +441,10 @@ void DFontPreviewItemDelegate::paintForegroundPreviewFont(QPainter *painter, con
 *************************************************************************/
 void DFontPreviewItemDelegate::paintBackground(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paintBackground";
     DPalette::ColorGroup colorGroup = option.state.testFlag(QStyle::State_Enabled) ? DPalette::Normal : DPalette::Disabled;
     if (colorGroup == DPalette::Normal && false == option.state.testFlag(QStyle::State_Active)) {
+        // qDebug() << "Setting color group to Inactive";
         colorGroup = DPalette::Inactive;
     }
 
@@ -357,10 +462,13 @@ void DFontPreviewItemDelegate::paintBackground(QPainter *painter, const QStyleOp
     }
 
     if (option.state.testFlag(QStyle::State_Selected)) {
+        // qDebug() << "Item is selected";
         //如果是通过tab获取到的焦点，绘制tab的选中效果
         if (m_parentView->getIsTabFocus() == true) {
+            // qDebug() << "Using tab focus background";
             paintTabFocusBackground(painter, option, bgRect);
         } else {
+            // qDebug() << "Using normal selected background";
             //不是通过tab获取到的焦点的情况，再去绘制默认的选中状态，避免的tab选中状态时四个角会出现直角的问题
             DStyleHelper styleHelper;
             QColor fillColor = styleHelper.getColor(static_cast<const QStyleOption *>(&option), DPalette::ToolTipText);
@@ -370,6 +478,7 @@ void DFontPreviewItemDelegate::paintBackground(QPainter *painter, const QStyleOp
             painter->fillPath(path, fillColor);
         }
     } else {
+        // qDebug() << "Item is not selected, using default background";
 #if QT_VERSION_MAJOR > 5
         DPalette pa = DGuiApplicationHelper::instance()->applicationPalette();
 #else
@@ -380,6 +489,7 @@ void DFontPreviewItemDelegate::paintBackground(QPainter *painter, const QStyleOp
         painter->setBrush(QBrush(fillColor));
         painter->fillPath(path, fillColor);
     }
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paintBackground";
 }
 
 /*************************************************************************
@@ -395,6 +505,7 @@ void DFontPreviewItemDelegate::paintBackground(QPainter *painter, const QStyleOp
 *************************************************************************/
 void DFontPreviewItemDelegate::paintTabFocusBackground(QPainter *painter, const QStyleOptionViewItem &option, const QRect &bgRect) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paintTabFocusBackground";
     //初始化绘制高亮色区域路径
     QPainterPath path;
     painter->setRenderHint(QPainter::Antialiasing, true);
@@ -428,6 +539,7 @@ void DFontPreviewItemDelegate::paintTabFocusBackground(QPainter *painter, const
     fillColor3.setAlphaF(0.2);
     painter->setBrush(QBrush(fillColor3));
     painter->fillPath(path3, painter->brush());
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paintTabFocusBackground";
 }
 
 /*************************************************************************
@@ -445,6 +557,7 @@ void DFontPreviewItemDelegate::paintTabFocusBackground(QPainter *painter, const
 *************************************************************************/
 void DFontPreviewItemDelegate::setPaintPath(const QRect &bgRect, QPainterPath &path, const int xDifference, const int yDifference, const int radius) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::setPaintPath";
     QPoint path_bottomRight(bgRect.bottomRight().x() - xDifference, bgRect.bottomRight().y() - yDifference);
     QPoint path_topRight(bgRect.topRight().x() - xDifference, bgRect.topRight().y() + yDifference);
     QPoint path_topLeft(bgRect.topLeft().x() + xDifference, bgRect.topLeft().y() + yDifference);
@@ -458,6 +571,7 @@ void DFontPreviewItemDelegate::setPaintPath(const QRect &bgRect, QPainterPath &p
     path.arcTo(QRect(QPoint(path_bottomLeft - QPoint(0, radius * 2)), QSize(radius * 2, radius * 2)), 180, 90);
     path.lineTo(path_bottomRight - QPoint(10, 0));
     path.arcTo(QRect(QPoint(path_bottomRight - QPoint(radius * 2, radius * 2)), QSize(radius * 2, radius * 2)), 270, 90);
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::setPaintPath";
 }
 
 
@@ -475,7 +589,9 @@ void DFontPreviewItemDelegate::setPaintPath(const QRect &bgRect, QPainterPath &p
 void DFontPreviewItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
                                      const QModelIndex &index) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::paint";
     if (index.isValid()) {
+        // qDebug() << "Index is valid, proceeding with painting";
         painter->save();
         painter->setRenderHint(QPainter::TextAntialiasing, true);
 
@@ -500,8 +616,10 @@ void DFontPreviewItemDelegate::paint(QPainter *painter, const QStyleOptionViewIt
                                    fontPixelSize, fontPreviewContent);
         painter->restore();
     } else {
+        // qDebug() << "Index is invalid, delegating to parent paint";
         QStyledItemDelegate::paint(painter, option, index);
     }
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::paint";
 }
 
 /*************************************************************************
@@ -516,20 +634,24 @@ void DFontPreviewItemDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 *************************************************************************/
 QSize DFontPreviewItemDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::sizeHint";
     FontData data = index.data(Qt::DisplayRole).value<FontData>();
     int fontSize = (false == index.data(FontSizeRole).isNull()) ? index.data(FontSizeRole).toInt() : FTM_DEFAULT_PREVIEW_FONTSIZE;
 
     int itemHeight = FTM_PREVIEW_ITEM_HEIGHT;
 #ifdef DTKWIDGET_CLASS_DSizeMode
     if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+        // qDebug() << "Using compact mode for item height";
         itemHeight = FTM_PREVIEW_ITEM_COMPACT_HEIGHT;
     }
 #endif
 
     if (fontSize > 30) {
+        // qDebug() << "Font size is larger than 30, adjusting item height";
         itemHeight += static_cast<int>(((fontSize - 30) + 1) * 1.5);
     }
 
+    // qDebug() << "Exiting function: DFontPreviewItemDelegate::sizeHint";
     return QSize(option.rect.width(), itemHeight);
 }
 
@@ -545,8 +667,10 @@ QSize DFontPreviewItemDelegate::sizeHint(const QStyleOptionViewItem &option, con
 *************************************************************************/
 bool DFontPreviewItemDelegate::eventFilter(QObject *object, QEvent *event)
 {
+    // qDebug() << "Entering function: DFontPreviewItemDelegate::eventFilter";
     Q_UNUSED(object)
     if (event->type() == QEvent::HoverLeave) {
+        // qDebug() << "Processing HoverLeave event";
         DFontPreviewListView *listview = qobject_cast<DFontPreviewListView *>(parent());
         listview->clearHoverState();
         listview->clearPressState(DFontPreviewListView::ClearType::PreviousClear);
