@@ -44,6 +44,7 @@ const QString FONT_SYSTEM_DIR = "/usr/share/fonts/";
 *************************************************************************/
 inline bool isSystemFont(const QString &filePath)
 {
+    // qDebug() << "Entering function: isSystemFont";
     if (filePath.contains("/usr/share/fonts/")) {
         return true;
     } else {
@@ -63,6 +64,7 @@ inline bool isSystemFont(const QString &filePath)
 *************************************************************************/
 QString convertToUtf8(unsigned char *content, unsigned int len)
 {
+    // qDebug() << "Entering function: convertToUtf8";
     QString convertedStr = "";
 
     std::size_t inputBufferSize = static_cast<std::size_t>(len);
@@ -97,6 +99,7 @@ QString getDefaultPreviewText(FT_Face face, qint8 &lang, int len = FTM_DEFAULT_P
 *************************************************************************/
 QString getDefaultPreviewText(FT_Face face, qint8 &lang, int len)
 {
+    // qDebug() << "Entering function: getDefaultPreviewText";
     QString previewTxt;
 
     if (face == nullptr || face->num_charmaps == 0)
@@ -107,6 +110,7 @@ QString getDefaultPreviewText(FT_Face face, qint8 &lang, int len)
 
     //first check chinese preview
     if (DFontPreview::checkFontContainText(face, FTM_DEFAULT_PREVIEW_CN_TEXT)) {
+        // qDebug() << "Font contains Chinese preview text";
         lang = FONT_LANG_CHINESE;
         if (language.startsWith("zh_")) {
             return previewTxt;
@@ -115,23 +119,26 @@ QString getDefaultPreviewText(FT_Face face, qint8 &lang, int len)
 
     //not support chinese preview, than check english preview
     if (DFontPreview::checkFontContainText(face, FTM_DEFAULT_PREVIEW_EN_TEXT)) {
+        // qDebug() << "Font contains English preview text";
         lang |= FONT_LANG_ENGLISH;
         return previewTxt;
     }
 
     if (DFontPreview::checkFontContainText(face, FTM_DEFAULT_PREVIEW_DIGIT_TEXT)) {
+        // qDebug() << "Font contains digit preview text";
         lang = FONT_LANG_DIGIT;
         return previewTxt;
     }
 
+    // qDebug() << "Exiting function: getDefaultPreviewText";
     return DFontPreview::buildCharlistForFace(face, len);
 }
 
 DFontInfoManager *DFontInfoManager::instance()
 {
-    qDebug() << "Getting DFontInfoManager instance";
+    // qDebug() << "Getting DFontInfoManager instance";
     if (!INSTANCE) {
-        qDebug() << "Creating new DFontInfoManager instance";
+        // qDebug() << "Creating new DFontInfoManager instance";
         INSTANCE = new DFontInfoManager;
     }
 
@@ -142,6 +149,7 @@ DFontInfoManager::DFontInfoManager(QObject *parent)
     : QObject(parent)
     , m_strSysLanguage(QLocale::system().name())
 {
+    qDebug() << "Entering function: DFontInfoManager::DFontInfoManager";
     //Should not be called in constructor
     //refreshList();
 
@@ -161,19 +169,24 @@ DFontInfoManager::DFontInfoManager(QObject *parent)
                         TT_MS_LANGID_UIGHUR_PRC,
                         TT_MS_LANGID_YI_PRC};
     if (langmap.contains(m_strSysLanguage)) {
+        // qDebug() << "Language contains in langmap";
         m_langpriority3 = langmap.value(m_strSysLanguage);
         if (cnlangset.contains(m_langpriority3)) {
+            // qDebug() << "Language contains in cnlangset";
             m_langpriority2 = TT_MS_LANGID_CHINESE_PRC;
             m_langpriority1 = TT_MS_LANGID_ENGLISH_UNITED_STATES;
         } else {
+            // qDebug() << "Language does not contain in cnlangset";
             m_langpriority2 = TT_MS_LANGID_ENGLISH_UNITED_STATES;
             m_langpriority1 = TT_MS_LANGID_ENGLISH_UNITED_STATES;
         }
     } else {
+        // qDebug() << "Language does not contain in langmap";
         m_langpriority3 = TT_MS_LANGID_ENGLISH_UNITED_STATES;
         m_langpriority2 = TT_MS_LANGID_ENGLISH_UNITED_STATES;
         m_langpriority1 = TT_MS_LANGID_ENGLISH_UNITED_STATES;
     }
+    qDebug() << "Exiting function: DFontInfoManager::DFontInfoManager";
 }
 
 DFontInfoManager::~DFontInfoManager() {}
@@ -202,6 +215,7 @@ void DFontInfoManager::refreshList(const QStringList &allFontPathList)
     }
 
     updateSP3FamilyName(dataList);
+    qDebug() << "Exiting function: DFontInfoManager::refreshList";
 }
 
 /*************************************************************************
@@ -224,6 +238,7 @@ QStringList DFontInfoManager::getAllFontPath(bool isStartup) const
     pathList = getAllFclistPathList();
 
     if (isStartup) {
+        qDebug() << "Getting system font files";
         //系统字体文件
         QStringList systemfilelist = getFileNames(FONT_SYSTEM_DIR);
         for (const QString &str : systemfilelist) {
@@ -241,11 +256,13 @@ QStringList DFontInfoManager::getAllFontPath(bool isStartup) const
         }
     }
 
+    qDebug() << "Exiting function: DFontInfoManager::getAllFontPath";
     return pathList;
 }
 
 QStringList DFontInfoManager::getAllFclistPathList() const
 {
+    qDebug() << "Entering function: DFontInfoManager::getAllFclistPathList";
     QProcess process;
     QStringList pathList;
 
@@ -262,6 +279,7 @@ QStringList DFontInfoManager::getAllFclistPathList() const
             pathList << filePath;
         }
     }
+    qDebug() << "Exiting function: DFontInfoManager::getAllFclistPathList";
     return pathList;
 }
 
@@ -299,6 +317,7 @@ QStringList DFontInfoManager::getFileNames(const QString &path)const
         QString absolute_file_path = file_info.absoluteFilePath();
         string_list.append(absolute_file_path);
     }
+    qDebug() << "Exiting function: DFontInfoManager::getFileNames";
     return string_list;
 }
 
@@ -313,6 +332,7 @@ QStringList DFontInfoManager::getFileNames(const QString &path)const
 *************************************************************************/
 QStringList DFontInfoManager::getAllChineseFontPath() const
 {
+    qDebug() << "Entering function: DFontInfoManager::getAllChineseFontPath";
     QStringList pathList;
     QProcess process;
     process.start("fc-list", QStringList() << ":lang=zh");
@@ -328,6 +348,7 @@ QStringList DFontInfoManager::getAllChineseFontPath() const
         }
     }
 
+    qDebug() << "Exiting function: DFontInfoManager::getAllChineseFontPath";
     return pathList;
 #if 0
     return getFonts(Chinese);
@@ -345,6 +366,7 @@ QStringList DFontInfoManager::getAllChineseFontPath() const
 *************************************************************************/
 QStringList DFontInfoManager::getAllMonoSpaceFontPath() const
 {
+    qDebug() << "Entering function: DFontInfoManager::getAllMonoSpaceFontPath";
     QStringList pathList;
     QProcess process;
     process.start("fc-list", QStringList() << ":spacing=mono");
@@ -362,6 +384,7 @@ QStringList DFontInfoManager::getAllMonoSpaceFontPath() const
 #if 0
     QStringList pathList = getFonts(MonoSpace);
 #endif
+    qDebug() << "Exiting function: DFontInfoManager::getAllMonoSpaceFontPath";
     return pathList;
 }
 
@@ -388,6 +411,7 @@ QString DFontInfoManager::getFontType(const QString &filePath)
         qWarning() << "Unknown font type for:" << filePath;
         return FONT_UNKNOWN;
     }
+    qDebug() << "Exiting function: DFontInfoManager::getFontType";
 }
 
 struct NameIdFlag {
@@ -409,6 +433,7 @@ struct NameIdFlag {
 *************************************************************************/
 void DFontInfoManager::setFontInfo(DFontInfo& fontInfo)
 {
+    qDebug() << "Entering function: DFontInfoManager::setFontInfo";
     /*****************************************
     字体显示名称规则
     规则说明：
@@ -428,6 +453,7 @@ void DFontInfoManager::setFontInfo(DFontInfo& fontInfo)
     ****************************************/
     QString familyName;
     if (fontInfo.sp3FamilyName.isEmpty() || fontInfo.sp3FamilyName.contains(QChar('?'))) {
+        qDebug() << "Adding application font";
         int appFontId = QFontDatabase::addApplicationFont(fontInfo.filePath);
 
         QStringList fontFamilyList = QFontDatabase::applicationFontFamilies(appFontId);
@@ -437,35 +463,46 @@ void DFontInfoManager::setFontInfo(DFontInfo& fontInfo)
             familyName = family;
         }
         if (familyName.isEmpty()) {
+            qDebug() << "Family name is empty";
             if (!fontInfo.fullname.isEmpty() && !fontInfo.fullname.contains(QChar('?'))) {
+                qDebug() << "Full name is not empty";
                 familyName = fontInfo.fullname;
             } else if (!fontInfo.psname.isEmpty() && !fontInfo.psname.contains(QChar('?'))) {
+                qDebug() << "PS name is not empty";
                 familyName = fontInfo.fullname;
             } else {
+                qDebug() << "Full name and PS name are empty";
                 familyName = QLatin1String("UntitledFont");
             }
         }
         fontInfo.sp3FamilyName = familyName;
     } else {
+        qDebug() << "Family name is not empty";
         familyName = fontInfo.sp3FamilyName;
     }
 
     if (!fontInfo.styleName.isEmpty() && !familyName.endsWith(fontInfo.styleName) && familyName != QLatin1String("UntitledFont")) {
+        qDebug() << "Style name is not empty";
         fontInfo.familyName = familyName;//从Sfnt接口获取的familyname读取宋体文件时解析为韩语或者?，替换为字体显示名称
     } else {
+        qDebug() << "Style name is empty";
         //从Sfnt接口获取的familyname读取宋体文件时解析为韩语或者?，替换为字体显示名称
         // 例如Consolas-Regular(或Consolas Regular)获取到Consolas
         if(fontInfo.styleName.isEmpty()){
+            qDebug() << "Style name is empty";
             fontInfo.familyName = familyName;
         }
         else {
 #if QT_VERSION_MAJOR > 5
+            qDebug() << "Style name is not empty";
             fontInfo.familyName = familyName.replace(QRegularExpression(QString("[ -]" + fontInfo.styleName + "$")), "");
 #else
+            qDebug() << "Style name is not empty";
             fontInfo.familyName = familyName.replace(QRegExp(QString("[ -]" + fontInfo.styleName + "$")), "");
 #endif
         }
     }
+    qDebug() << "Exiting function: DFontInfoManager::setFontInfo";
     return;
 }
 
@@ -600,6 +637,7 @@ DFontInfo DFontInfoManager:: getFontInfo(const QString &filePath, bool withPrevi
     }
     //compitable with SP2 update1 and previous versions
     if (!fontInfo.fullname.isEmpty()) {
+        qDebug() << "Full name is not empty";
         // 例如Consolas-Regular(或Consolas Regular)获取到Consolas
 #if QT_VERSION_MAJOR > 5
         fontInfo.familyName = fontInfo.fullname.replace(QRegularExpression(QString("[ -]" + fontInfo.styleName + "$")), "");
@@ -609,16 +647,19 @@ DFontInfo DFontInfoManager:: getFontInfo(const QString &filePath, bool withPrevi
     }
 
     if (fontInfo.familyName.trimmed().length() < 1) {
+        qDebug() << "Family name is empty";
         fontInfo.familyName = QString::fromLatin1(face->family_name).trimmed();
     }
 
     // 防止部分sp3FamilyName乱码
     if (flagsetsp3FN) {
+        qDebug() << "Flag set SP3 family name";
         fontInfo.sp3FamilyName = fontInfo.familyName;
     }
 
     //default preview text
     if (withPreviewTxt) {
+        qDebug() << "With preview text";
         if (fontInfo.familyName == "Noto Sans Grantha") {
             fontInfo.defaultPreview = getDefaultPreviewText(face, fontInfo.previewLang, INT_MAX);
         } else {
@@ -637,18 +678,23 @@ DFontInfo DFontInfoManager:: getFontInfo(const QString &filePath, bool withPrevi
 
     DFMDBManager *dbManager = DFMDBManager::instance();
     if (dbManager->getRecordCount() > 0) {
+        qDebug() << "Database record count is greater than 0";
         fontInfo.sysVersion = fontInfo.version;
         if (dbManager->isFontInfoExist(fontInfo).isEmpty()) {
+            qDebug() << "Font info does not exist";
             fontInfo.isInstalled = false;
         } else {
+            qDebug() << "Font info exists";
             fontInfo.isInstalled = true;
         }
     } /*else {
         fontInfo.isInstalled = isFontInstalled(fontInfo);
     }*/
     if(!fontInfo.isInstalled){
+        qDebug() << "Font info does not exist in database";
         fontInfo.isInstalled = isFontInInstalledDirs(fontInfo.filePath);
     }
+    qDebug() << "Exiting function: DFontInfoManager::getFontInfo";
     return fontInfo;
 }
 
@@ -664,6 +710,7 @@ DFontInfo DFontInfoManager:: getFontInfo(const QString &filePath, bool withPrevi
 *************************************************************************/
 QString DFontInfoManager::getDefaultPreview(const QString &filePath, qint8 &preivewLang)
 {
+    qDebug() << "Entering function: DFontInfoManager::getDefaultPreview";
     FT_Library m_library = nullptr;
     FT_Face m_face = nullptr;
     QString defaultPreview;
@@ -683,6 +730,7 @@ QString DFontInfoManager::getDefaultPreview(const QString &filePath, qint8 &prei
     defaultPreview = getDefaultPreviewText(m_face, preivewLang);
     FT_Done_Face(m_face);
     FT_Done_FreeType(m_library);
+    qDebug() << "Exiting function: DFontInfoManager::getDefaultPreview";
     return defaultPreview;
 }
 
@@ -697,6 +745,7 @@ QString DFontInfoManager::getDefaultPreview(const QString &filePath, qint8 &prei
 *************************************************************************/
 QStringList DFontInfoManager::getCurrentFontFamily()
 {
+    qDebug() << "Entering function: DFontInfoManager::getCurrentFontFamily";
     QStringList retStrList;
     QProcess process;
 
@@ -763,6 +812,7 @@ QStringList DFontInfoManager::getCurrentFontFamily()
     FcFontSetDestroy(fs);
     FcFini();
 #endif
+    qDebug() << "Exiting function: DFontInfoManager::getCurrentFontFamily";
     return retStrList;
 }
 
@@ -777,6 +827,7 @@ QStringList DFontInfoManager::getCurrentFontFamily()
 *************************************************************************/
 QString DFontInfoManager::getFontPath()
 {
+    qDebug() << "Entering function: DFontInfoManager::getFontPath";
     QString filePath;
     QStringList retStrList;
     QProcess process;
@@ -803,6 +854,7 @@ QString DFontInfoManager::getFontPath()
             }
         }
     }
+    qDebug() << "Exiting function: DFontInfoManager::getFontPath";
     return filePath;
 }
 
@@ -817,7 +869,7 @@ QString DFontInfoManager::getFontPath()
 *************************************************************************/
 QStringList DFontInfoManager::getFontFamilyStyle(const QString &filePah)
 {
-
+    qDebug() << "Entering function: DFontInfoManager::getFontFamilyStyle";
     QStringList fontFamilyList;
     const FcChar8 *format = reinterpret_cast<const FcChar8 *>("%{=fclist}");
     FcObjectSet *os = FcObjectSetBuild(FC_FAMILY, FC_STYLE, FC_FILE, nullptr);
@@ -829,6 +881,7 @@ QStringList DFontInfoManager::getFontFamilyStyle(const QString &filePah)
     if (pat)
         FcPatternDestroy(pat);
     if (fs) {
+        qDebug() << "Font set is not empty";
         for (int j = 0; j < fs->nfont; j++) {
             FcChar8 *s = FcPatternFormat(fs->fonts[j], format);
             if (s == nullptr)
@@ -838,6 +891,7 @@ QStringList DFontInfoManager::getFontFamilyStyle(const QString &filePah)
             QStringList retStrList = str.split(":");
 
             if (retStrList.size() != 3) {
+                // qDebug() << "Ret list size is not 3";
                 FcStrFree(s);
                 continue;
             }
@@ -861,6 +915,7 @@ QStringList DFontInfoManager::getFontFamilyStyle(const QString &filePah)
 
 //    FcFini();
 
+    qDebug() << "Exiting function: DFontInfoManager::getFontFamilyStyle";
     return fontFamilyList;
 }
 
@@ -875,6 +930,7 @@ QStringList DFontInfoManager::getFontFamilyStyle(const QString &filePah)
 *************************************************************************/
 QStringList DFontInfoManager::getFonts(DFontInfoManager::FontTYpe type) const
 {
+    qDebug() << "Entering function: DFontInfoManager::getFonts";
     QStringList fontList;
     const FcChar8 *format = reinterpret_cast<const FcChar8 *>("%{=fclist}");
     FcPattern *pat = nullptr;
@@ -909,6 +965,7 @@ QStringList DFontInfoManager::getFonts(DFontInfoManager::FontTYpe type) const
         FcPatternDestroy(pat);
 
     if (fs) {
+        qDebug() << "Font set is not empty";
         for (int j = 0; j < fs->nfont; j++) {
             FcChar8 *s = FcPatternFormat(fs->fonts[j], format);
             if (s == nullptr)
@@ -925,6 +982,7 @@ QStringList DFontInfoManager::getFonts(DFontInfoManager::FontTYpe type) const
     }
 
 //    FcFini();
+    qDebug() << "Exiting function: DFontInfoManager::getFonts";
     return fontList;
 }
 
@@ -939,6 +997,7 @@ QStringList DFontInfoManager::getFonts(DFontInfoManager::FontTYpe type) const
 *************************************************************************/
 bool DFontInfoManager::isFontInstalled(DFontInfo &data)
 {
+    qDebug() << "Entering function: DFontInfoManager::isFontInstalled";
     for (DFontInfo &item : dataList) {
         if (data == item) {
             data.sysVersion = item.version;
@@ -946,6 +1005,7 @@ bool DFontInfoManager::isFontInstalled(DFontInfo &data)
         }
     }
 
+    qDebug() << "Exiting function: DFontInfoManager::isFontInstalled";
     return false;
 }
 
@@ -960,16 +1020,21 @@ bool DFontInfoManager::isFontInstalled(DFontInfo &data)
 *************************************************************************/
 bool DFontInfoManager::isFontInInstalledDirs(const QString &filePath)
 {
+    qDebug() << "Entering function: DFontInfoManager::isFontInInstalledDirs";
     if (filePath.contains(QDir::homePath() + "/.local/share/fonts/")) {
+        qDebug() << "File path contains .local/share/fonts";
         return true;
     }
     if (filePath.lastIndexOf("/") < 0){
+        qDebug() << "File path last index of / is less than 0";
         return false;
     }
     QFile file(QDir::homePath() + "/.local/share/fonts" + filePath.mid(filePath.lastIndexOf("/")));
     if (file.exists()) {
+        qDebug() << "File exists";
         return true;
     }
+    qDebug() << "Exiting function: DFontInfoManager::isFontInInstalledDirs";
     return false;
 }
 
@@ -984,6 +1049,7 @@ bool DFontInfoManager::isFontInInstalledDirs(const QString &filePath)
 *************************************************************************/
 void DFontInfoManager::getDefaultPreview(DFontInfo &data)
 {
+    qDebug() << "Entering function: DFontInfoManager::getDefaultPreview";
 //    for (DFontInfo &item : dataList) {
 //        if (data == item) {
 //            data.defaultPreview = item.defaultPreview;
@@ -993,6 +1059,7 @@ void DFontInfoManager::getDefaultPreview(DFontInfo &data)
 //    }
 
     data.defaultPreview = getDefaultPreview(data.filePath, data.previewLang);
+    qDebug() << "Exiting function: DFontInfoManager::getDefaultPreview";
 }
 
 /**
@@ -1003,10 +1070,12 @@ void DFontInfoManager::getDefaultPreview(DFontInfo &data)
 */
 void DFontInfoManager::updateSP3FamilyName(const QList<DFontInfo> &fontList, bool inFontList)
 {
+    qDebug() << "Entering function: DFontInfoManager::updateSP3FamilyName";
     if (fontList.isEmpty())
         return;
     //compitable with sp2 update1 and previous versions
     DFMDBManager::instance()->updateSP3FamilyName(fontList,  inFontList);
+    qDebug() << "Exiting function: DFontInfoManager::updateSP3FamilyName";
 }
 
 /*************************************************************************
@@ -1020,47 +1089,68 @@ void DFontInfoManager::updateSP3FamilyName(const QList<DFontInfo> &fontList, boo
 *************************************************************************/
 void DFontInfoManager::checkStyleName(DFontInfo &f)
 {
+    qDebug() << "Entering function: DFontInfoManager::checkStyleName";
     //有些字体文件因为不规范导致的stylename为空，通过psname来判断该字体的stylename。
     //之前代码顺序出现问题，导致有的时候contains判断出错 比如DemiBold与Bold，现在调整代码顺序
     if (f.styleName.contains("?") || f.styleName.isEmpty()) {
+        qDebug() << "Style name contains ? or is empty";
         if (f.psname != "") {
+            qDebug() << "PS name is not empty";
             if (f.psname.contains("Regular", Qt::CaseInsensitive)) {
                 f.styleName = "Regular";
             } else if (f.psname.contains("DemiBold", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains DemiBold";
                 f.styleName = "DemiBold";
             } else if (f.psname.contains("ExtraBold", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains ExtraBold";
                 f.styleName = "ExtraBold";
             } else if (f.psname.contains("Bold", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Bold";
                 f.styleName = "Bold";
             } else if (f.psname.contains("ExtraLight", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains ExtraLight";
                 f.styleName = "ExtraLight";
             } else if (f.psname.contains("Light", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Light";
                 f.styleName = "Light";
             } else if (f.psname.contains("Thin", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Thin";
                 f.styleName = "Thin";
             } else if (f.psname.contains("Medium", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Medium";
                 f.styleName = "Medium";
             } else if (f.psname.contains("AnyStretch", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains AnyStretch";
                 f.styleName = "AnyStretch";
             } else if (f.psname.contains("UltraCondensed", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains UltraCondensed";
                 f.styleName = "UltraCondensed";
             } else if (f.psname.contains("ExtraCondensed", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains ExtraCondensed";
                 f.styleName = "ExtraCondensed";
             } else if (f.psname.contains("SemiCondensed", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains SemiCondensed";
                 f.styleName = "SemiCondensed";
             } else if (f.psname.contains("Condensed", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Condensed";
                 f.styleName = "Condensed";
             } else if (f.psname.contains("Unstretched", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Unstretched";
                 f.styleName = "Unstretched";
             } else if (f.psname.contains("SemiExpanded", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains SemiExpanded";
                 f.styleName = "SemiExpanded";
             } else if (f.psname.contains("ExtraExpanded", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains ExtraExpanded";
                 f.styleName = "ExtraExpanded";
             } else if (f.psname.contains("UltraExpanded", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains UltraExpanded";
                 f.styleName = "UltraExpanded";
             } else if (f.psname.contains("Expanded", Qt::CaseInsensitive)) {
+                qDebug() << "PS name contains Expanded";
                 f.styleName = "Expanded";
             } else {
+                qDebug() << "PS name contains Unknown";
                 f.styleName = "Unknown";
             }
         }
@@ -1069,4 +1159,5 @@ void DFontInfoManager::checkStyleName(DFontInfo &f)
 //            f.styleName = "Unknown";
 //        }
     }
+    qDebug() << "Exiting function: DFontInfoManager::checkStyleName";
 }
