@@ -46,6 +46,7 @@ DFontPreview::DFontPreview(QWidget *parent)
     setFixedSize(FIXED_WIDTH, FIXED_HEIGHT);
     //    setFixedSize(static_cast<int>(qApp->primaryScreen()->geometry().width() / 1.5),
     //                 static_cast<int>(qApp->primaryScreen()->geometry().height() / 1.5));
+    qDebug() << "Exiting function: DFontPreview::DFontPreview";
 }
 
 /*************************************************************************
@@ -58,8 +59,10 @@ DFontPreview::DFontPreview(QWidget *parent)
 *************************************************************************/
 DFontPreview::~DFontPreview()
 {
+    // qDebug() << "Entering function: DFontPreview::~DFontPreview";
     FT_Done_Face(m_face);
     FT_Done_FreeType(m_library);
+    // qDebug() << "Exiting function: DFontPreview::~DFontPreview";
 }
 
 /*************************************************************************
@@ -89,6 +92,7 @@ void DFontPreview::setFileUrl(const QString &url)
     styleName = QString(m_face->style_name);
 
     repaint();
+    qDebug() << "Exiting function: DFontPreview::setFileUrl";
 }
 
 /*************************************************************************
@@ -102,6 +106,7 @@ void DFontPreview::setFileUrl(const QString &url)
 *************************************************************************/
 void DFontPreview::paintEvent(QPaintEvent *e)
 {
+    // qDebug() << "Painting font preview";
     currentMaxWidth = 1;
     if (m_error != 0) {
         qWarning() << "Cannot paint preview - font loading error";
@@ -133,6 +138,7 @@ void DFontPreview::paintEvent(QPaintEvent *e)
 
     /*根据获取的新point进行绘制 UT000539 fix bug 27030*/
     if (checkFontContainText(m_face, lowerTextStock)) {
+        // qDebug() << "Font contains lowercase text";
 #if QT_VERSION_MAJOR > 5
         const int lowerWidth = metrics.boundingRect(lowerTextStock).width();
 #else
@@ -141,11 +147,33 @@ void DFontPreview::paintEvent(QPaintEvent *e)
         isNeedScroll(lowerWidth);
         const int lowerHeight = metrics.height();
         QPoint baseLinePoint = adjustPreviewFontBaseLinePoint(QRect(x, y + padding, lowerWidth, lowerHeight), metrics);
+        
+        // 检查字体边界框是否异常，某些特殊字体可能有异常的度量值
+        QRect textBounds = metrics.boundingRect(lowerTextStock);
+        
+        // 特殊处理水平位置异常的字体
+        if (textBounds.x() < -5) {
+            // 如果文本边界框有负x偏移，强制修正基线点的x坐标
+            int correctionOffset = qAbs(textBounds.x()) + 2; // 额外加2像素安全边距
+            baseLinePoint.setX(x + correctionOffset);
+        }
+        
+        // 特殊处理高度异常的字体，确保不会超出显示区域
+        int actualTextHeight = textBounds.height();
+        if (actualTextHeight > lowerHeight * 1.5) {
+            // 如果文本实际高度明显超过预期，调整基线位置
+            int adjustedY = y + padding + actualTextHeight * 0.8;
+            if (adjustedY < baseLinePoint.y()) {
+                baseLinePoint.setY(adjustedY);
+            }
+        }
+        
         painter.drawText(baseLinePoint.x(), baseLinePoint.y(), lowerTextStock);
         y += lowerHeight;
     }
 
     if (checkFontContainText(m_face, upperTextStock)) {
+        // qDebug() << "Font contains uppercase text";
 #if QT_VERSION_MAJOR > 5
         const int upperWidth = metrics.boundingRect(upperTextStock).width();
 #else
@@ -154,11 +182,33 @@ void DFontPreview::paintEvent(QPaintEvent *e)
         isNeedScroll(upperWidth);
         const int upperHeight = metrics.height();
         QPoint baseLinePoint = adjustPreviewFontBaseLinePoint(QRect(x, y + padding, upperWidth, upperHeight), metrics);
+        
+        // 检查字体边界框是否异常，某些特殊字体可能有异常的度量值
+        QRect textBounds = metrics.boundingRect(upperTextStock);
+        
+        // 特殊处理水平位置异常的字体
+        if (textBounds.x() < -5) {
+            // 如果文本边界框有负x偏移，强制修正基线点的x坐标
+            int correctionOffset = qAbs(textBounds.x()) + 2; // 额外加2像素安全边距
+            baseLinePoint.setX(x + correctionOffset);
+        }
+        
+        // 特殊处理高度异常的字体，确保不会超出显示区域
+        int actualTextHeight = textBounds.height();
+        if (actualTextHeight > upperHeight * 1.5) {
+            // 如果文本实际高度明显超过预期，调整基线位置
+            int adjustedY = y + padding + actualTextHeight * 0.8;
+            if (adjustedY < baseLinePoint.y()) {
+                baseLinePoint.setY(adjustedY);
+            }
+        }
+        
         painter.drawText(baseLinePoint.x(), baseLinePoint.y(), upperTextStock);
         y += upperHeight;
     }
 
     if (checkFontContainText(m_face, punctuationTextStock)) {
+        // qDebug() << "Font contains punctuation text";
 #if QT_VERSION_MAJOR > 5
         const int punWidth = metrics.boundingRect(punctuationTextStock).width();
 #else
@@ -167,6 +217,27 @@ void DFontPreview::paintEvent(QPaintEvent *e)
         isNeedScroll(punWidth);
         int punHeight = metrics.height();
         QPoint baseLinePoint = adjustPreviewFontBaseLinePoint(QRect(x, y + padding, punWidth, punHeight), metrics);
+        
+        // 检查字体边界框是否异常，某些特殊字体可能有异常的度量值
+        QRect textBounds = metrics.boundingRect(punctuationTextStock);
+        
+        // 特殊处理水平位置异常的字体
+        if (textBounds.x() < -5) {
+            // 如果文本边界框有负x偏移，强制修正基线点的x坐标
+            int correctionOffset = qAbs(textBounds.x()) + 2; // 额外加2像素安全边距
+            baseLinePoint.setX(x + correctionOffset);
+        }
+        
+        // 特殊处理高度异常的字体，确保不会超出显示区域
+        int actualTextHeight = textBounds.height();
+        if (actualTextHeight > punHeight * 1.5) {
+            // 如果文本实际高度明显超过预期，调整基线位置
+            int adjustedY = y + padding + actualTextHeight * 0.8;
+            if (adjustedY < baseLinePoint.y()) {
+                baseLinePoint.setY(adjustedY);
+            }
+        }
+        
         painter.drawText(baseLinePoint.x(), baseLinePoint.y(), punctuationTextStock);
         y += punHeight;
     }
@@ -189,19 +260,43 @@ void DFontPreview::paintEvent(QPaintEvent *e)
             break;
 
         QPoint baseLinePoint = adjustPreviewFontBaseLinePoint(QRect(x, y + padding * 2, sampleWidth, sampleHeight), met);
+        
+        // 检查字体边界框是否异常，某些特殊字体可能有异常的度量值
+        QRect textBounds = met.boundingRect(sampleString);
+        
+        // 特殊处理水平位置异常的字体
+        if (textBounds.x() < -5) {
+            // 如果文本边界框有负x偏移，强制修正基线点的x坐标
+            int correctionOffset = qAbs(textBounds.x()) + 2; // 额外加2像素安全边距
+            baseLinePoint.setX(x + correctionOffset);
+        }
+        
+        // 特殊处理高度异常的字体，确保不会超出显示区域
+        int actualTextHeight = textBounds.height();
+        if (actualTextHeight > sampleHeight * 1.5) {
+            // 如果文本实际高度明显超过预期，调整基线位置
+            int adjustedY = y + padding * 2 + actualTextHeight * 0.8;
+            if (adjustedY < baseLinePoint.y()) {
+                baseLinePoint.setY(adjustedY);
+            }
+        }
+        
         painter.drawText(baseLinePoint.x(), baseLinePoint.y(), sampleString);
         y += sampleHeight + padding;
     }
     /*判断是否需要滚动条 UT000539*/
     if (currentMaxWidth > viewWidth) {
+        // qDebug() << "Current max width is greater than view width, setting fixed width to:" << currentMaxWidth;
         setFixedWidth(currentMaxWidth);
         m_needScroll = true;
     } else {
+        // qDebug() << "Current max width is less than view width, setting fixed width to:" << FIXED_WIDTH;
 //        setFixedWidth(static_cast<int>(qApp->primaryScreen()->geometry().width() / 1.5));
         setFixedWidth(FIXED_WIDTH);
         m_needScroll = false;
     }
     QWidget::paintEvent(e);
+    // qDebug() << "Exiting function: DFontPreview::paintEvent";
 }
 
 /*************************************************************************
@@ -215,14 +310,18 @@ void DFontPreview::paintEvent(QPaintEvent *e)
 *************************************************************************/
 void DFontPreview::isNeedScroll(const int width)
 {
+    // qDebug() << "Checking if need scroll, width:" << width;
     if (m_needScroll == false) {
+        // qDebug() << "Need scroll, setting m_needScroll to true";
         if (width > textWidth) {
             m_needScroll = true;
         }
     }
     if (width > currentMaxWidth) {
+        // qDebug() << "Current max width is greater than width, setting currentMaxWidth to:" << width;
         currentMaxWidth = width;
     }
+    // qDebug() << "Exiting function: DFontPreview::isNeedScroll";
 }
 
 /*************************************************************************
@@ -255,6 +354,7 @@ void DFontPreview::initContents()
 
         m_contents.insert(items.at(0), items.at(1));
     }
+    qDebug() << "Exiting function: DFontPreview::initContents";
 }
 
 /*************************************************************************
@@ -267,6 +367,7 @@ void DFontPreview::initContents()
 *************************************************************************/
 QString DFontPreview::getSampleString()
 {
+    qDebug() << "Getting sample string";
     //[CPPCHECK]
     //局部变量sampleString与全局变量名称重复，更名sampString
     QString sampString = nullptr;
@@ -280,6 +381,7 @@ QString DFontPreview::getSampleString()
 
     // check english sample string.
     if (!isAvailable) {
+        qDebug() << "English sample string is not available, getting language sample string";
         sampString = getLanguageSampleString("en");
         if (checkFontContainText(m_face, sampString)) {
             isAvailable = true;
@@ -288,9 +390,11 @@ QString DFontPreview::getSampleString()
 
     // random string from available chars.
     if (!isAvailable) {
+        qDebug() << "Random string is not available, building character list for face";
         sampString = buildCharlistForFace(m_face, 36);
     }
 
+    qDebug() << "Exiting function: DFontPreview::getSampleString";
     return sampString;
 }
 
@@ -305,11 +409,14 @@ QString DFontPreview::getSampleString()
 *************************************************************************/
 QString DFontPreview::getLanguageSampleString(const QString &language)
 {
+    qDebug() << "Getting language sample string for language:" << language;
     QString result = nullptr;
     QString key = nullptr;
     if (m_contents.contains(language)) {
+        qDebug() << "Language sample string is available for language:" << language;
         key = language;
     } else {
+        qDebug() << "Language sample string is not available for language:" << language;
 #if QT_VERSION_MAJOR > 5
         const QStringList parseList = language.split("_", Qt::SkipEmptyParts);
 #else
@@ -317,15 +424,18 @@ QString DFontPreview::getLanguageSampleString(const QString &language)
 #endif
         if (parseList.length() > 0 &&
                 m_contents.contains(parseList.first())) {
+            qDebug() << "Language sample string is available for language:" << parseList.first();
             key = parseList.first();
         }
     }
 
     if (m_contents.contains(key)) {
+        qDebug() << "Language sample string is available for language:" << key;
         auto findResult = m_contents.find(key);
         result.append(findResult.value());
     }
 
+    qDebug() << "Exiting function: DFontPreview::getLanguageSampleString";
     return result;
 }
 
@@ -351,6 +461,7 @@ bool DFontPreview::checkFontContainText(FT_Face face, const QString &text)
     if (face->charmap == nullptr)
         err = FT_Select_Charmap(face, FT_ENCODING_UNICODE);
     if (err != 0) {
+        qDebug() << "Failed to select charmaps, trying to select charmaps";
         for (int i = 0; i < face->num_charmaps; ++i) {
             err = FT_Select_Charmap(face, face->charmaps[i]->encoding);
             if (err == 0) {
@@ -367,6 +478,7 @@ bool DFontPreview::checkFontContainText(FT_Face face, const QString &text)
         }
     }
 
+    qDebug() << "Exiting function: DFontPreview::checkFontContainText";
     return retval;
 }
 
@@ -382,12 +494,14 @@ bool DFontPreview::checkFontContainText(FT_Face face, const QString &text)
 *************************************************************************/
 bool isSpecialSymbol(FT_Face face, uint ucs4)
 {
+    qDebug() << "Checking if character is special symbol:" << ucs4;
     unsigned int glyph = FT_Get_Char_Index(face, ucs4);
     int err;
 
     err = FT_Load_Glyph(face, glyph, FT_LOAD_NO_SCALE);
 
     if (err == 0 && face->glyph->metrics.width == 0 && face->glyph->metrics.height == 0) {
+        qDebug() << "Character is special symbol";
         return true;
     }
 
@@ -411,6 +525,7 @@ bool isSpecialSymbol(FT_Face face, uint ucs4)
             || ((ucs4 >= 0x11300 && ucs4 <= 0x11303) || (ucs4 >= 0x1CD0 && ucs4 <= 0x1cF9) || (ucs4 == 0x20F0) || (ucs4 >= 0xD800 && ucs4 <= 0xDFFF)) //grantha
             || (ucs4  >= 0x10A01 && ucs4 <= 0x10A0F) || (ucs4 >= 0x10A38 && ucs4 <= 0x10A3F)) // kharoshthi
         return true;
+    qDebug() << "Character is not special symbol";
     return false;
 }
 
@@ -448,6 +563,7 @@ QString DFontPreview::buildCharlistForFace(FT_Face face, int length)
 
     QList<uint> ucs4List;
     if (count > 0) {
+        qDebug() << "Count is greater than 0, building character list for face";
         FcChar32 ucs4, pos, map[FC_CHARSET_MAP_SIZE];
         int retCount = 0;
         uint unicode = 0;
@@ -478,6 +594,7 @@ QString DFontPreview::buildCharlistForFace(FT_Face face, int length)
         int index = 0;
 
         if (static_cast<int>(count) > len) {
+            qDebug() << "Count is greater than len, finding index";
             for (int i = len - 2; i >= 0; i--) {
                 if (firstChar - ucs4List[i] > static_cast<uint>((len - 1 - i) + len - 1)) {
                     index = i + 1;
@@ -508,6 +625,7 @@ QString DFontPreview::buildCharlistForFace(FT_Face face, int length)
     // Destroy a character set
     FcCharSetDestroy(fcs);
 
+    qDebug() << "Exiting function: DFontPreview::buildCharlistForFace";
     return retval;
 }
 
@@ -523,10 +641,33 @@ QString DFontPreview::buildCharlistForFace(FT_Face face, int length)
 *************************************************************************/
 QPoint DFontPreview::adjustPreviewFontBaseLinePoint(const QRect &fontPreviewRect, const QFontMetrics &previewFontMetrics) const
 {
-    Q_UNUSED(previewFontMetrics);
-    int commonFontDescent = fontPreviewRect.height() / 4;
+    // qDebug() << "Adjusting preview font base line point";
     int baseLineX = fontPreviewRect.x();
-    int baseLineY = fontPreviewRect.bottom() - commonFontDescent;
+    int baseLineY;
+    
+    if (previewFontMetrics.height() > 0 && previewFontMetrics.ascent() > 0 && previewFontMetrics.descent() >= 0) {
+        // 使用实际的字体度量信息来计算基线位置
+        // 确保文字不会超出预览区域的边界
+        int actualHeight = previewFontMetrics.height();
+        int availableHeight = fontPreviewRect.height();
+        
+        if (actualHeight <= availableHeight) {
+            // 字体高度适合预览区域，居中显示
+            int verticalPadding = (availableHeight - actualHeight) / 2;
+            baseLineY = fontPreviewRect.top() + verticalPadding + previewFontMetrics.ascent();
+        } else {
+            // 字体太高，需要缩放显示位置以避免超出边界
+            // 计算缩放比例
+            double scaleFactor = (double)availableHeight / actualHeight * 0.9; // 留10%的边距
+            int adjustedAscent = (int)(previewFontMetrics.ascent() * scaleFactor);
+            baseLineY = fontPreviewRect.top() + (availableHeight - (int)(actualHeight * scaleFactor)) / 2 + adjustedAscent;
+        }
+    } else {
+        // 回退到原来的固定比例计算方式，但使用更保守的比例
+        int commonFontDescent = fontPreviewRect.height() / 5; // 保持1/5，这里预览区域通常较大
+        baseLineY = fontPreviewRect.bottom() - commonFontDescent;
+    }
 
+    // qDebug() << "Exiting function: DFontPreview::adjustPreviewFontBaseLinePoint";
     return QPoint(baseLineX, baseLineY);
 }
